@@ -3,3 +3,5 @@ from serverless.service.plugins.domain_manager import DomainManager
 from serverless.service.plugins.generic import Generic
 from serverless.service.plugins.prune import Prune
 from serverless.service.plugins.python_requirements import PythonRequirements
+from serverless.service.plugins.step_functions import StepFunctions
+from serverless.service.plugins.vpc_discovery import VpcDiscovery
